# Turn off the brp-java-repack-jars script
%global __os_install_post %(echo '%{__os_install_post}' | sed -e 's!/usr/lib[^[:space:]]*/brp-java-repack-jars[[:space:]].*$!!g')

Name: argus-pep-server

Version: 1.6.1
Release: 1%{?dist}
Summary: Argus PEP Server

Group: System Environment/Daemons
License: ASL 2.0
URL: https://twiki.cern.ch/twiki/bin/view/EGEE/AuthorizationFramework

Source: %{name}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch: noarch

BuildRequires: java-devel
BuildRequires: jpackage-utils
BuildRequires: maven

Requires: java
Requires: jpackage-utils
Requires: redhat-lsb
Requires: argus-pep-common >= 2.3
Requires: argus-pdp-pep-common >= 1.4
Requires: voms-api-java3

%description 
Argus PEP (Policy Enforcement Point) Server.
The Argus Authorization Service renders consistent authorization 
decisions for distributed services (e.g., user interfaces, 
portals, computing elements, storage elements). The service is 
based on the XACML standard, and uses authorization policies to 
determine if a user is allowed or denied to perform a certain 
action on a particular service.
.
The Argus Authorization Service is composed of three main 
components:
- The Policy Administration Point (PAP) provides the tools to 
author authorization policies, organize them in the local 
repository and configure policy distribution among remote PAPs.
- The Policy Decision Point (PDP) implements the authorization 
engine, and is responsible for the evaluation of the authorization
requests against the XACML policies retrieved from the PAP.
- The Policy Enforcement Point Server (PEP Server) ensures the 
integrity and consistency of the authorization requests received 
from the PEP clients. Lightweight PEP client libraries are also 
provided to ease the integration and interoperability with other 
EMI services or components. 

%prep
%setup -q

%build
export JAVA_HOME=/usr/lib/jvm/java
make package

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=$RPM_BUILD_ROOT install

%clean
rm -rf $RPM_BUILD_ROOT


%pre
# on install (1): nothing
# on upgrade (2): stop the service, and clean up the lib directory
if [ $1 -eq 2 ] ; then
    /sbin/service argus-pepd stop > /dev/null 2>&1 || :
    # delete old jar 
    find /var/lib/argus/pepd/lib -name "*.jar" -exec rm {} \;
fi


%post
# on install (1): register the service in init.d
# on upgrade (2): nothing
if [ $1 -eq 1 ]; then 
    /sbin/chkconfig --add argus-pepd
fi
# correct files/dirs permission
chmod -f 640 %{_sysconfdir}/argus/pepd/pepd.ini
chmod -f 750 %{_datadir}/argus/pepd/sbin/pepdctl
chmod -f 750 %{_localstatedir}/log/argus/pepd


%preun
# on uninstall (0): stop and deregister the service
# on upgrade (1): nothing
if [ $1 -eq 0 ] ; then
    /sbin/service argus-pepd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del argus-pepd
fi

%postun
# on uninstall (0): nothing
# on upgrade (1): restart the service 
if [ $1 -eq 1 ] ; then
    /sbin/service argus-pepd start
fi


%files
%defattr(-,root,root,-)
%{_sysconfdir}/init.d/argus-pepd
%dir %{_sysconfdir}/argus/pepd
%config(noreplace) %{_sysconfdir}/argus/pepd/logging.xml
%config(noreplace) %{_sysconfdir}/argus/pepd/pepd.ini
%config(noreplace) %{_sysconfdir}/sysconfig/argus-pepd
%{_sbindir}/pepdctl
%dir %{_datadir}/argus/pepd
%dir %{_datadir}/argus/pepd/sbin
%{_datadir}/argus/pepd/logs
%{_datadir}/argus/pepd/conf
%{_datadir}/argus/pepd/doc
%{_datadir}/argus/pepd/lib
%{_datadir}/argus/pepd/sbin/pepdctl
%dir %{_defaultdocdir}/argus/pepd
%{_defaultdocdir}/argus/pepd/COPYRIGHT
%{_defaultdocdir}/argus/pepd/LICENSE
%{_defaultdocdir}/argus/pepd/RELEASE-NOTES
%dir %{_localstatedir}/lib/argus/pepd/lib
%{_localstatedir}/lib/argus/pepd/lib/argus-pepd-1.6.1.jar
%{_localstatedir}/lib/argus/pepd/lib/commons-codec-1.3.jar
%{_localstatedir}/lib/argus/pepd/lib/commons-collections-3.1.jar
%{_localstatedir}/lib/argus/pepd/lib/commons-httpclient-3.0.1.jar
%{_localstatedir}/lib/argus/pepd/lib/commons-io-1.4.jar
%{_localstatedir}/lib/argus/pepd/lib/commons-lang-2.1.jar
%{_localstatedir}/lib/argus/pepd/lib/ehcache-core-1.7.2.jar

%{_localstatedir}/lib/argus/pepd/lib/ini4j-0.5.2.jar
%{_localstatedir}/lib/argus/pepd/lib/jcl-over-slf4j-1.5.8.jar
%{_localstatedir}/lib/argus/pepd/lib/jetty-6.1.18.jar
%{_localstatedir}/lib/argus/pepd/lib/jetty-java5-threadpool-6.1.18.jar
%{_localstatedir}/lib/argus/pepd/lib/jetty-sslengine-6.1.18.jar
%{_localstatedir}/lib/argus/pepd/lib/jetty-util-6.1.18.jar
%{_localstatedir}/lib/argus/pepd/lib/jna-3.0.9.jar
%{_localstatedir}/lib/argus/pepd/lib/jna-posix-1.0.3.jar
%{_localstatedir}/lib/argus/pepd/lib/joda-time-1.6.jar
%{_localstatedir}/lib/argus/pepd/lib/jul-to-slf4j-1.5.8.jar
%{_localstatedir}/lib/argus/pepd/lib/log4j-over-slf4j-1.5.8.jar
%{_localstatedir}/lib/argus/pepd/lib/logback-classic-0.9.18.jar
%{_localstatedir}/lib/argus/pepd/lib/logback-core-0.9.18.jar
%{_localstatedir}/lib/argus/pepd/lib/not-yet-commons-ssl-0.3.9.jar
%{_localstatedir}/lib/argus/pepd/lib/opensaml-2.3.2.jar
%{_localstatedir}/lib/argus/pepd/lib/openws-1.3.1.jar
%{_localstatedir}/lib/argus/pepd/lib/servlet-api-2.5-20081211.jar
%{_localstatedir}/lib/argus/pepd/lib/slf4j-api-1.5.8.jar
%{_localstatedir}/lib/argus/pepd/lib/velocity-1.5.jar
%{_localstatedir}/lib/argus/pepd/lib/xmlsec-1.4.3.jar
%{_localstatedir}/lib/argus/pepd/lib/xmltooling-1.2.2.jar
%dir %{_localstatedir}/lib/argus/pepd/lib/endorsed
%{_localstatedir}/lib/argus/pepd/lib/endorsed/serializer-2.7.1.jar
%{_localstatedir}/lib/argus/pepd/lib/endorsed/xalan-2.7.1.jar
%{_localstatedir}/lib/argus/pepd/lib/endorsed/xercesImpl-2.9.1.jar
%{_localstatedir}/lib/argus/pepd/lib/endorsed/xml-apis-1.3.04.jar
%{_localstatedir}/lib/argus/pepd/lib/endorsed/xml-resolver-1.2.jar
%dir %{_localstatedir}/lib/argus/pepd/lib/provided
%{_localstatedir}/lib/argus/pepd/lib/provided/bcmail-*.jar
%{_localstatedir}/lib/argus/pepd/lib/provided/bcprov-*.jar
%{_localstatedir}/lib/argus/pepd/lib/provided/canl-*.jar
%{_localstatedir}/lib/argus/pepd/lib/provided/voms-api-java-*.jar
%dir %{_localstatedir}/log/argus/pepd

%changelog
* Fri Apr 5 2013 Valery Tschopp <valery.tschopp@switch.ch> 1.6.1-1
- Upstream version 1.6.1 for EMI-3 update.

* Wed Jan 30 2013 Valery Tschopp <valery.tschopp@switch.ch> 1.6.0-3
- Upstream version 1.6.0 for EMI-3 release.

* Tue Jan 29 2013 Valery Tschopp <valery.tschopp@switch.ch> 1.6.0-2 
- Upstream version 1.6.0 for EMI-3 (RC2).

* Thu Nov 18 2012 Valery Tschopp <valery.tschopp@switch.ch> 1.6.0-1 
- Upstream version 1.6.0 for EMI-3 (RC1).

* Mon Jul 30 2012 Valery Tschopp <valery.tschopp@switch.ch> 1.5.2-1
- Self managed packaging with spec file.

* Tue Apr 3 2012 Valery Tschopp <valery.tschopp@switch.ch> 1.5.1-1
- Initial Argus PDP for EMI 2.

